<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://brightminded.com
 * @since             1.0.0
 * @package           Dash_Effortless_Digital_Asset_Management
 *
 * @wordpress-plugin
 * Plugin Name:       Dash Effortless Digital Asset Management
 * Plugin URI:
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.0.0
 * Author:            Dash
 * Author URI:        https://dash.app
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       dash-effortless-digital-asset-management
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DASH_EFFORTLESS_DIGITAL_ASSET_MANAGEMENT_VERSION', '1.0.0' );

/**
 * The base url of the DASH API 
 */
define( 'DASH_API_BASE_URL', 'https://api-v1.brightdash.app' );

/**
 * The base url for the OAuth2 based authentication with the DASH REST API
 */
define( 'DASH_LOGIN_BASE_URL', 'https://login.brightdash.app' );

/**
 * The path where the OAuth callback functionality is to be found.
 */
define( 'DASH_OAUTH_REDIRECT_URI', admin_url( 'admin.php?page=dash_auth' ) );

/**
 * The key to identify the OAuth redirect URI
 */
define( 'DASH_OAUTH_REDIRECT_URI_KEY', 'redirect_uri' );

/**
 * The key that identifies an authenticated token from the DASH API
 */
define( 'DASH_AUTHENTICATED_TOKEN_KEY', 'dash_access_token' );

/**
 * The default value for the audience property to be passed to the DASH API
 * during OAuth authentication.
 */
define( 'DASH_OAUTH_AUDIENCE', 'https://assetplatform.io' );

/**
 * The default value for the scope property to be passed to the DASH API
 * during OAuth authentication.
 */
define( 'DASH_OAUTH_DEFAULT_SCOPE', 'offline_access openid profile email' );

/**
 * The key in the wp_options table to identify a DASH client id
 */
define( 'DASH_OAUTH_DB_CLIENT_ID_KEY', 'dash_client_id' );

/**
 * The key in the wp_options table to identify a DASH client secret
 */
define( 'DASH_OAUTH_DB_CLIENT_SECRET_KEY', 'dash_client_secret' );

/**
 * The key in the wp_options table to identify a DASH client subdomain
 */
define( 'DASH_OAUTH_DB_CLIENT_SUBDOMAIN_KEY', 'dash_client_subdomain' );

/**
 * Key to identify the new DASH Editor Role.
 */
define( 'DASH_ROLE_NAME', 'dash_content_editor' );

/**
 * Key to identify the new DASH Editor Role capability.
 */
define( 'DASH_ROLE_CAPABILITY', 'access_site_dash_api' );

/**
 * The maximum number of retries when polling the DASH API for a download 
 */
define( 'DASH_MAX_DOWNLOAD_RETRIES', 10 );

/**
 * The interval in microseconds between successive polling calls to the DASH API
 */
define( 'DASH_DOWNLOAD_POLL_INTERVAL_MICROS', 200000 ); //200 millis

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-dash-effortless-digital-asset-management-activator.php
 */
function activate_dash_effortless_digital_asset_management() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dash-effortless-digital-asset-management-activator.php';
	Dash_Effortless_Digital_Asset_Management_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-dash-effortless-digital-asset-management-deactivator.php
 */
function deactivate_dash_effortless_digital_asset_management() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dash-effortless-digital-asset-management-deactivator.php';
	Dash_Effortless_Digital_Asset_Management_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_dash_effortless_digital_asset_management' );
register_deactivation_hook( __FILE__, 'deactivate_dash_effortless_digital_asset_management' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-dash-effortless-digital-asset-management.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_dash_effortless_digital_asset_management() {

	$plugin = new Dash_Effortless_Digital_Asset_Management();
	$plugin->run();

}
run_dash_effortless_digital_asset_management();
