<?php

/**
 * Fired during plugin activation
 *
 * @link       https://brightminded.com
 * @since      1.0.0
 *
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 * @author     Brightminded <brightminded@brightminded.com>
 */
class Dash_Effortless_Digital_Asset_Management_Activator {

	/**
	 * It initialises the required option keys into the database.
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {

		self::add_dash_content_editor_role();
		self::add_dash_capabilties();

		add_option( DASH_OAUTH_DB_CLIENT_ID_KEY, false );
		add_option( DASH_OAUTH_DB_CLIENT_SECRET_KEY, false );
		add_option( DASH_OAUTH_DB_CLIENT_SUBDOMAIN_KEY, false );
		add_option( DASH_AUTHENTICATED_TOKEN_KEY, false );

	}

	/**
	 * Adds the new DASH role with access to the DASH functionality. 
	 * 
	 * @access  private
	 * @since	1.0.0
	 */
	private static function add_dash_capabilties() {

		$dash_content_editor = get_role( DASH_ROLE_NAME );
		$admin               = get_role( 'administrator' );

		$dash_content_editor->add_cap( DASH_ROLE_CAPABILITY, true );
		$admin->add_cap( DASH_ROLE_CAPABILITY, true );

	}

	/**
	 * It adds a new role for Dash editor which inherits from an editor.
	 * 
	 * @access	private
	 * @since	1.0.0
	 */
	private static function add_dash_content_editor_role() {

		$editor = get_role( 'editor' );

		add_role( 

			DASH_ROLE_NAME,
			'Dash Content Editor',
			$editor->capabilities
		
		);

	}

}
