<?php

/**
 * Fired during plugin deactivation
 *
 * @link       https://brightminded.com
 * @since      1.0.0
 *
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 */

/**
 * Fired during plugin deactivation.
 *
 * This class defines all code necessary to run during the plugin's deactivation.
 *
 * @since      1.0.0
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 * @author     Brightminded <brightminded@brightminded.com>
 */
class Dash_Effortless_Digital_Asset_Management_Deactivator {

	/**
	 * It cleans up various options from the database.
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function deactivate() {

		self::remove_dash_capabilties();
		self::remove_dash_content_editor_role();

		delete_option( DASH_OAUTH_DB_CLIENT_ID_KEY );
		delete_option( DASH_OAUTH_DB_CLIENT_SECRET_KEY );
		delete_option( DASH_OAUTH_DB_CLIENT_SUBDOMAIN_KEY );
		delete_option( DASH_AUTHENTICATED_TOKEN_KEY );

	}

	/**
	 * It remove the capabilities for the Dash Role.
	 * 
	 * @access 	private
	 * @since 	1.0.0
	 */
	private static function remove_dash_capabilties() {

		$role = get_role( DASH_ROLE_NAME );

		// add a custom capability
		// you can remove the 'edit_others-post' and add something else (your own custom capability) which you can use in your code login along with the current_user_can( $capability ) hook.
		if ( ! empty( $role ) ) 
			$role->remove_cap( DASH_ROLE_CAPABILITY );
		
	}

	/**
	 * It removes the Dash Role from the system.
	 * 
	 * @access 	private
	 * @since	1.0.0
	 */
	private static function remove_dash_content_editor_role() {

		remove_role(
			
			DASH_ROLE_NAME
		
		);

	}

}
