<?php 
/**
 * Simple wrapper for logging messages with the canonical levels ERROR, WARN, INFO, DEBUG.
 *
 * @link       https://brightminded.com
 * @since      1.0.0
 *
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 */

/**
 * This class defines a simple logging wrapper to error_log.
 *
 * @since      1.0.0
 * @package    Dash_Effortless_Digital_Asset_Management
 * @subpackage Dash_Effortless_Digital_Asset_Management/includes
 * @author     Brightminded <brightminded@brightminded.com>
 */
class Dash_Effortless_Digital_Asset_Management_Logging {

    const DEBUG = 'DEBUG';
    const INFO  = 'INFO';
    const WARN  = 'WARN';
    const ERROR = 'ERROR';

    const NAME2LEVEL = array(

        'debug' => self::DEBUG,
        'info'  => self::INFO,
        'warn'  => self::WARN,
        'error' => self::ERROR
    
    );
    
    /**
     * It adds nice formatting and a log level to error_log.
     *      
     * @since    1.0.0
     * @access   private
     * @param    string  $level     One of the canonical log levels.
     * @param    string  $source    The issuer of this log, typically a class or a function name.
     * @param    string  $message   The actual log message of interest.
     * 
     */
    private static function log( $level, $source, $message ) {

        $record = sprintf( '[%s] [%s] [%s] %s', date( 'Y-m-d H:i:s' ), $source, $level, $message );
        error_log( $record );

    }

    /**
     * Magic static method that allows to output a log of a certain level 
     * by calling a function with the name of the level, e.g. Dash_Effortless_Digital_Asset_Management_Logging::debug() or Dash_Effortless_Digital_Asset_Management_Logging::error()
     *      
     * @since    1.0.0
     * @access   private
     * @param    string  $level     One of the canonical log levels.
     * @param    string  $source    The issuer of this log, typically a class or a function name.
     * @param    string  $message   The actual log message of interest.
     * 
     */
    public static function __callStatic( string $name, array $arguments ) {

        if ( in_array( $name, array_keys( self::NAME2LEVEL ) ) ) {

            return self::log( self::NAME2LEVEL[ $name ], ...$arguments );

        }

    }

}